@@ -9,6 +9,7 @@ use Mojo::mysql::PubSub;
 use Mojo::URL;
 use Scalar::Util 'weaken';
 
+has auto_migrate    => 0;
 has dsn             => 'dbi:mysql:dbname=test';
 has max_connections => 5;
 has migrations      => sub {
@@ -17,13 +18,7 @@ has migrations      => sub {
   return $migrations;
 };
 has options => sub {
-  {
-    mysql_enable_utf8 => 1,
-    AutoCommit => 1,
-    AutoInactiveDestroy => 1,
-    PrintError => 0,
-    RaiseError => 1
-  }
+  {mysql_enable_utf8 => 1, AutoCommit => 1, AutoInactiveDestroy => 1, PrintError => 0, RaiseError => 1};
 };
 has [qw(password username)] => '';
 has pubsub => sub {
@@ -33,7 +28,7 @@ has pubsub => sub {
 };
 
 
-our $VERSION = '0.13';
+our $VERSION = '0.14';
 
 sub db {
   my $self = shift;
@@ -87,9 +82,13 @@ sub _dequeue {
   # you, silently, but only if certain env vars are set
   # hint: force-set mysql_auto_reconnect or whatever it's called to 0
   $dbh->{mysql_auto_reconnect} = 0;
+
   # Maintain Commits with Mojo::mysql::Transaction
   $dbh->{AutoCommit} = 1;
 
+  ++$self->{migrated} and $self->migrations->migrate
+    if !$self->{migrated} and $self->auto_migrate;
+
   $self->emit(connection => $dbh);
   [$dbh];
 }
@@ -186,7 +185,7 @@ gracefully by holding on to them only for short amounts of time.
   use Mojo::mysql;
 
   helper mysql =>
-    sub { state $pg = Mojo::mysql->new('mysql://sri:s3cret@localhost/db') };
+    sub { state $mysql = Mojo::mysql->new('mysql://sri:s3cret@localhost/db') };
 
   get '/' => sub {
     my $c  = shift;
@@ -240,6 +239,16 @@ Emitted when a new database connection has been established.
 
 L<Mojo::mysql> implements the following attributes.
 
+=head2 auto_migrate
+
+  my $bool = $mysql->auto_migrate;
+  $mysql   = $mysql->auto_migrate($bool);
+
+Automatically migrate to the latest database schema with L</"migrations">, as
+soon as the first database connection has been established.
+
+Defaults to false.
+
 =head2 dsn
 
   my $dsn = $mysql->dsn;
