@@ -5,15 +5,15 @@ use DBD::mysql;
 use Mojo::IOLoop;
 use Mojo::mysql::Results;
 use Mojo::mysql::Transaction;
-use Mojo::Util 'deprecated';
 use Scalar::Util 'weaken';
 
 has [qw(dbh mysql)];
 
 sub DESTROY {
   my $self = shift;
-  return unless my $dbh   = $self->dbh;
-  return unless my $mysql = $self->mysql;
+  my $waiting = $self->{waiting} || [];
+  $_->{cb}($self, 'Premature connection close', undef) for @$waiting;
+  return unless (my $mysql = $self->mysql) && (my $dbh = $self->dbh);
   $mysql->_enqueue($dbh, $self->{handle});
 }
 
@@ -21,7 +21,6 @@ sub backlog { scalar @{shift->{waiting} || []} }
 
 sub begin {
   my $self = shift;
-  $self->dbh->begin_work;
   my $tx = Mojo::mysql::Transaction->new(db => $self);
   weaken $tx->{db};
   return $tx;
@@ -29,19 +28,11 @@ sub begin {
 
 sub disconnect {
   my $self = shift;
+  $_->finish for @{$self->{async_sth} || []};
   $self->_unwatch;
   $self->dbh->disconnect;
 }
 
-# DEPRECATED!
-sub do {
-  deprecated 'Mojo::mysql::Database::do is DEPRECATED'
-    . ' in favor of Mojo::mysql::Database::query';
-  my $self = shift;
-  $self->dbh->do(@_);
-  return $self;
-}
-
 sub pid { shift->dbh->{mysql_thread_id} }
 
 sub ping { shift->dbh->ping }
@@ -53,7 +44,7 @@ sub query {
   # Blocking
   unless ($cb) {
     my $sth = $self->dbh->prepare($query);
-    my $rv = $sth->execute(@_);
+    my $rv  = $sth->execute(@_);
     my $res = Mojo::mysql::Results->new(sth => $sth);
     $res->{affected_rows} = defined $rv && $rv >= 0 ? 0 + $rv : undef;
     return $res;
@@ -85,7 +76,6 @@ sub _unwatch {
   my $self = shift;
   return unless delete $self->{watching};
   Mojo::IOLoop->singleton->reactor->remove($self->{handle});
-
   $self->{async_sth} = [];
 }
 
